@@ -12,6 +12,7 @@ class Initializer(object):
 		super(Initializer, self).__init__()
 		self.storage = storage
 		self.dataset = storage.loadDataset()
+		self.user = user
 		
 		# prefixes
 		if self.storage.type == 'local':
@@ -25,7 +26,7 @@ class Initializer(object):
 			self.prefix_commit = '.stack/'+self.storage.dataset+'commits/'
 			self.prefix_diffs = '.stack/'+self.storage.dataset+'diffs/'
 
-		self.user = user
+		self.start_check()
 
 	def defineSchema(self):
 		# defines the dataset schema for exporting and visualizing
@@ -38,6 +39,32 @@ class Initializer(object):
 			self.storage.removeFileGlobal('.stack/')
 		return True
 
+	def start_check(self):
+		# checks if the dataset exists
+		if not self.verify_setup():
+			print('no .stack/ folder found! creating one...')
+			self.setupDataset()
+		return True
+
+	def verify_setup(self):
+		# verifies if a setup .stack/ directory exists
+		if self.storage.checkIfEmpty(self.prefix_meta):
+			return False
+
+		if self.storage.checkIfEmpty(self.prefix_curr):
+			print('no diffs metadata found')
+			return False
+
+		if self.storage.checkIfEmpty(self.prefix_diffs):
+			print('no diffs found')
+			return False
+
+		if self.storage.checkIfEmpty(self.prefix_commit):
+			print('no commits metada found')
+			return False
+
+		return True
+
 	def setupDataset(self):
 		# performs all key operations
 		self.copyCurrent()
